# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------


DURATION_DAYS = 10675199
DURATION_MIN = 10085
DURATION_SECS = 4775807
DURATION_LIMIT = 10675198
SYSTEM = 'SystemAssigned'
USER = 'UserAssigned'
SYSTEMUSER = 'SystemAssigned, UserAssigned'
